@@ -1,11 +1,10 @@
 import os
 import numpy as np
 from osgeo import ogr, osr
-from shapely.wkt import loads
+#from shapely.wkt import loads
 from pyflowline.classes.vertex import pyvertex
 
-
-import importlib
+import importlib.util
 iFlag_cython = importlib.util.find_spec("cython") 
 if iFlag_cython is not None:
     from pyflowline.algorithms.cython.kernel import find_vertex_in_list
@@ -22,7 +21,7 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
     if os.path.exists(sFilename_output_in): 
         os.remove(sFilename_output_in)
     
-    pDriver_geojson = ogr.GetDriverByName( "GeoJSON")
+    pDriver_geojson = ogr.GetDriverByName("GeoJSON")
     pDataset_flowline_a = pDriver_geojson.Open(sFilename_flowline_a_in, 0)
     pDataset_flowline_b = pDriver_geojson.Open(sFilename_flowline_b_in, 0)   
     pLayer_flowline_a = pDataset_flowline_a.GetLayer(0)
@@ -50,9 +49,9 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
 
     pDataset_out = pDriver_geojson.CreateDataSource(sFilename_output_in)
 
-    pLayerOut = pDataset_out.CreateLayer('flowline', pSpatial_reference_b, ogr.wkbMultiPoint)
+    pLayerOut = pDataset_out.CreateLayer('intersect', pSpatial_reference_b, ogr.wkbMultiPoint)
     # Add one attribute
-    pLayerOut.CreateField(ogr.FieldDefn('id', ogr.OFTInteger64)) #long type for high resolution
+    pLayerOut.CreateField(ogr.FieldDefn('pointid', ogr.OFTInteger64)) #long type for high resolution
     
     pLayerDefn = pLayerOut.GetLayerDefn()
     pFeatureOut = ogr.Feature(pLayerDefn)    
@@ -66,10 +65,11 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
         #pFeature_mesh= pLayer_mesh.GetFeature(i)
         pGeometry_flowline_a = pFeature_flowline_a.GetGeometryRef() 
         npoint = pFeature_flowline_a.GetPointCount()
-        aCoords = list()
+        aCoords_gcs = list()
         for i in range(0, npoint):                   
             pt = pFeature_flowline_a.GetPoint(i)
-            aCoords.append( [ pt[0], pt[1]])               
+            aCoords_gcs.append( [ pt[0], pt[1]])         
+
         aCoords_gcs= np.array(aCoords_gcs)       
 
         if (iFlag_transform ==1): #projections are different
@@ -82,10 +82,7 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
 
         #convert geometry to edge
         pGeometrytype_flowline_a = pGeometry_flowline_a.GetGeometryName()
-        if(pGeometrytype_flowline_a == 'LINESTRING'):            
-            
-                     
-            aFlowline_intersect = list()
+        if(pGeometrytype_flowline_a == 'LINESTRING'):                                                     
             iFlag_intersected = 0 
             for j in range (nfeature_flowline_b):
             #for pFeature_flowline in pLayer_flowline:
@@ -93,7 +90,7 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
                 pGeometry_flowline_b = pFeature_flowline_b.GetGeometryRef()
 
                 if iFlag_id ==1:
-                    lFlowlineID = pFeature_flowline_b.GetField("id")
+                    lFlowlineID = pFeature_flowline_b.GetField("lineid")
                 else:
                     lFlowlineID = -1
 
@@ -125,7 +122,7 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
                             else:                       
                                 aVertex_intersect.append(pVertex)
                                 pFeatureOut.SetGeometry(point)
-                                pFeatureOut.SetField("id", lVertexID)         
+                                pFeatureOut.SetField("pointid", lVertexID)         
                                 pLayerOut.CreateFeature(pFeatureOut)    
                                 lVertexID = lVertexID + 1
 
@@ -142,7 +139,7 @@ def intersect_flowline_with_flowline( sFilename_flowline_a_in, sFilename_flowlin
                         else:                
                             aVertex_intersect.append(pVertex)
                             pFeatureOut.SetGeometry(pGeometry_intersect)
-                            pFeatureOut.SetField("id", lVertexID)         
+                            pFeatureOut.SetField("pointid", lVertexID)         
                             pLayerOut.CreateFeature(pFeatureOut)    
                             lVertexID = lVertexID + 1                                        
                     
