@@ -1,16 +1,16 @@
 import copy
 import numpy as np
 from pyflowline.formats.convert_coordinates import convert_gcs_coordinates_to_flowline
-from pyflowline.algorithms.auxiliary.find_index_in_list import check_if_duplicates
 
 def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_in):    
     aFlowline_out=list()    
     nCell =  len(aCell_intersect_in)
+    #lCellID_to_cell = {cell.lCellID: cell for cell in aCell_intersect_in}
     def simplify_list(aCell_flowline_in):
         aCell_flowline_out = copy.deepcopy(aCell_flowline_in)
         nCell2 = len(aCell_flowline_out)          
-        iFlag_unique = check_if_duplicates(aCell_flowline_out)
-        if iFlag_unique == 1:
+        #iFlag_unique = check_if_duplicates(aCell_flowline_out)
+        if int(len(aCell_flowline_out) == len(set(aCell_flowline_out))) :
             return aCell_flowline_out
         else:
             for i in range(nCell2):
@@ -20,16 +20,13 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
                     start = dummy[0]
                     end = dummy[-1]
                     del aCell_flowline_out[start: end]                     
-                    break                    
-                else:
-                    pass
-
-                pass             
+                    break                                              
             
             aCell_flowline_out = simplify_list(aCell_flowline_out)
         return   aCell_flowline_out
-
+      
     def retrieve_flowline_intersect_index(iSegment_in, iStream_order_in, pVertex_end_in):
+        lCellID =-1       
         iFlag_found = 1
         pVertex_end_current = pVertex_end_in
         aCell_flowline=list()  
@@ -39,10 +36,10 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
         iFlag_skip = 0
         iFlag_previous_overlap=0
         while iFlag_found == 1:
-            iFlag_found = 0             
+            iFlag_found = 0                       
             for j in range(nCell):
                 pCell = aCell_intersect_in[j]
-                lCellID = pCell.lCellID
+                lCellID = pCell.lCellID               
                 aFlowline= pCell.aFlowline
                 nFlowline = len(aFlowline)
                 for i in range(nFlowline):
@@ -51,18 +48,16 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
                     pVertex_end = pFlowline.pVertex_end
                     iStream_segment = pFlowline.iStream_segment
                     iStream_order = pFlowline.iStream_order
-                    if pVertex_end == pVertex_end_current:
+                    if pVertex_end == pVertex_end_current: #be careful because this function is strict
                         if iStream_segment == iSegment_in:                            
                             dLength = pFlowline.dLength
                             iFlag_found2, dummy2 = pCell.which_edge_cross_this_vertex(pVertex_start)
                             iFlag_found3, dummy3 = pCell.which_edge_cross_this_vertex(pVertex_end)
-
                             if iFlag_found2 == 1 and iFlag_found3 == 1: #on the edge
                                 #same edge
                                 if dummy2.is_overlap(dummy3) ==1:                                    
                                     pVertex_end_current = pVertex_start    
-                                    aCell_flowline.append(lCellID)
-                                    #print(lCellID)
+                                    aCell_flowline.append(lCellID)                                    
                                     iFlag_found = 1                
                                     iFlag_previous_overlap =1
                                     
@@ -72,8 +67,7 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
                                         pVertex_end_current = pVertex_start   
                                         iFlag_found = 1                                          
                                         if iFlag_previous_overlap ==1: 
-                                            aCell_flowline.append(lCellID)              
-                                            #print(lCellID)
+                                            aCell_flowline.append(lCellID)  
                                             iFlag_previous_overlap=0
                                             pass
                                         else:
@@ -83,20 +77,14 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
                                     else:
                                         pVertex_end_current = pVertex_start    
                                         aCell_flowline.append(lCellID)
-                                        #print(lCellID)
-                                        iFlag_found = 1                                      
-                                        pass
-
-                                    pass                                
-
-                                pass
+                                        iFlag_found = 1                                     
+                                      
 
                             else:
                                 pVertex_end_current = pVertex_start    
                                 aCell_flowline.append(lCellID)                                
                                 iFlag_found = 1
-                                iFlag_previous_overlap=0
-                                pass                            
+                                iFlag_previous_overlap=0                                                       
                                 
                             break
                             
@@ -123,7 +111,7 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
         #should have finished search
         if iFlag_found == 0:
             #reverse 
-            aCell_flowline = aCell_flowline[::-1]
+            aCell_flowline = aCell_flowline[::-1]          
             #simplify list         
             aCell_simple = simplify_list(aCell_flowline)
             #save the output
@@ -137,51 +125,32 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
                             x = aCell_intersect_in[j].dLongitude_center_degree
                             y = aCell_intersect_in[j].dLatitude_center_degree                
                             aCoordinates.append([x,y])
-                    pass
+                 
                 pFlowline = convert_gcs_coordinates_to_flowline(aCoordinates)
                 pFlowline.iStream_segment = iSegment_in
                 pFlowline.iStream_order=iStream_order_in
                 aFlowline_out.append(pFlowline)
 
             sort_index = np.argsort(aStream_order)            
-            sort_index = sort_index[::-1]
-            nUpstream = len(aSegment_upstream)
+            #sort_index = sort_index[::-1] #can we process low order first?
+            #nUpstream = len(aSegment_upstream)
             for i in sort_index:
                 retrieve_flowline_intersect_index(aSegment_upstream[i], aStream_order[i], aVertex_end_upstream[i])
                 pass
             pass
 
         return 
-
-    #starting from the outlet
-    dDiatance_min=0.0
-    iFlag_first=1
-    for j in range(nCell):
-        pCell = aCell_intersect_in[j]
-        aFlowline= pCell.aFlowline
-        nFlowline = len(aFlowline)
-        for i in range(nFlowline):
-            pFlowline = aFlowline[i]
-            pVertex_start = pFlowline.pVertex_start
-            pVertex_end = pFlowline.pVertex_end
-            dDiatance = pVertex_end.calculate_distance( pVertex_outlet_in)
-            if iFlag_first ==1:
-                dDiatance_min = dDiatance               
-                lCellID_outlet = pCell.lCellID               
+    
+    dDiatance_min = float('inf')
+    lCellID_outlet = lCellID_outlet2 = lCellID_outlet3 = None    
+    for j, pCell in enumerate(aCell_intersect_in):
+        for i, pFlowline in enumerate(pCell.aFlowline):
+            dDiatance = pFlowline.pVertex_end.calculate_distance(pVertex_outlet_in)
+            if dDiatance < dDiatance_min:
+                dDiatance_min = dDiatance
+                lCellID_outlet = pCell.lCellID
                 lCellID_outlet2 = j
                 lCellID_outlet3 = i
-                iFlag_first=0
-            else:
-                if  dDiatance < dDiatance_min:
-                    dDiatance_min = dDiatance                
-                    lCellID_outlet = pCell.lCellID                
-                    lCellID_outlet2 = j
-                    lCellID_outlet3 = i
-                    pass    
-                else:
-                    pass
-
-            pass     
 
     #loop through       
     pFlowline = aCell_intersect_in[lCellID_outlet2].aFlowline[lCellID_outlet3]
@@ -191,4 +160,7 @@ def remove_returning_flowline(iMesh_type_in, aCell_intersect_in, pVertex_outlet_
         
     retrieve_flowline_intersect_index(iStream_segment, iStream_order, pVertex_outlet)
 
+    #update outlet location since the conceptual flowline use center
+    pVertex_outlet =  aFlowline_out[0].pVertex_end
+
     return aFlowline_out, lCellID_outlet, pVertex_outlet
