@@ -1,4 +1,4 @@
-import importlib
+import importlib.util
 import json
 from json import JSONEncoder
 import numpy as np
@@ -9,7 +9,7 @@ iFlag_cython = importlib.util.find_spec("cython")
 if iFlag_cython is not None:
     from pyflowline.algorithms.cython.kernel import calculate_angle_betwen_vertex
 else:
-    from pyflowline.algorithms.auxiliary.gdal_functions import  calculate_angle_betwen_vertex
+    from pyearth.gis.geometry.calculate_angle_betwen_vertex import  calculate_angle_betwen_vertex
 
 class ConfluenceClassEncoder(JSONEncoder):
     """Confluence Class Encoder
@@ -59,7 +59,7 @@ class pyconfluence():
         try:     
             self.pVertex_confluence      = pVertex_center       
             self.aFlowline_upstream      = aFlowline_upstream_in  
-            self.pFlowline_downstream      = pFlowline_downstream_in  
+            self.pFlowline_downstream    = pFlowline_downstream_in  
             
         except:
             print('Initialization of confluence failed!')
