@@ -7,7 +7,7 @@ from pyflowline.classes.vertex import pyvertex
 from pyflowline.classes.edge import pyedge
 from pyflowline.classes.cell import pycell
 from pyflowline.classes.flowline import pyflowline
-from pyflowline.algorithms.auxiliary.gdal_functions import calculate_polygon_area
+from pyearth.gis.geometry.calculate_polygon_area import calculate_polygon_area
 
 class MpasClassEncoder(JSONEncoder):
     def default(self, obj):
@@ -20,7 +20,7 @@ class MpasClassEncoder(JSONEncoder):
         if isinstance(obj, list):
             pass  
         if isinstance(obj, pyvertex):
-            return json.loads(obj.tojson()) #lVertexID
+            return json.loads(obj.tojson()) 
         if isinstance(obj, pyedge):
             return obj.lEdgeID        
         if isinstance(obj, pyflowline):
@@ -68,13 +68,17 @@ class pympas(pycell):
     aVertexID=None
     pVertex_center = None
     aFlowline=None    
-    nNeighbor=-1
+    nNeighbor=-1 
     nNeighbor_land=-1
+    nNeighbor_land_virtual = -1
+    aNeighbor_land_virtual = None
     nNeighbor_ocean=-1
-    aNeighbor=None #the global ID of all neighbors
+    aNeighbor=None #the global ID of all neighbors, execluding null
     aNeighbor_land=None #the global ID of all neighbors
+    
     aNeighbor_ocean=None #the global ID of all neighbors
     aNeighbor_distance = None
+    pBound=None
 
     def __init__(self, dLon, dLat, aEdge, aVertex):
         """
@@ -96,8 +100,10 @@ class pympas(pycell):
             self.aVertex = aVertex #the first one and last one are the same
             self.nEdge = len(aEdge)
             self.nVertex = len(aVertex) 
+            #initialize the neighbor but without the actual neighbor information
             self.nNeighbor = -1
             self.nNeighbor_land = -1
+            self.nNeighbor_land_virtual = -1
             self.nNeighbor_ocean = -1
             self.iFlag_coast = 0      
             self.dLongitude_center_degree = dLon
@@ -111,9 +117,22 @@ class pympas(pycell):
             self.iStream_segment_burned=-1
             self.dElevation_mean=-9999.0
             self.dElevation_profile0=-9999.0
+            self.calculate_cell_bound() #bound for rtree 
             pass
         pass
-    
+    def calculate_cell_bound(self):
+        dLat_min = 90
+        dLat_max = -90
+        dLon_min = 180
+        dLon_max = -180
+        for i in range(self.nVertex):
+            dLon_max = np.max( [dLon_max, self.aVertex[i].dLongitude_degree] )
+            dLon_min = np.min( [dLon_min, self.aVertex[i].dLongitude_degree] )
+            dLat_max = np.max( [dLat_max, self.aVertex[i].dLatitude_degree] )
+            dLat_min = np.min( [dLat_min, self.aVertex[i].dLatitude_degree] )
+        
+        self.pBound = (dLon_min, dLat_min, dLon_max, dLat_max)
+        return self.pBound
    
     def has_this_edge(self, pEdge_in):
         """
