@@ -1,9 +1,9 @@
 import os
 import numpy as np
 from osgeo import ogr, gdal
-from shapely.wkt import loads
+#from shapely.wkt import loads
 from pyflowline.formats.convert_coordinates import convert_gcs_coordinates_to_cell
-
+from pyearth.gis.location.get_geometry_coordinates import get_geometry_coordinates
 def read_mesh_json(iMesh_type_in, sFilename_mesh_in):
     """
     convert a shpefile to json format.
@@ -27,7 +27,7 @@ def read_mesh_json(iMesh_type_in, sFilename_mesh_in):
     for n in range(ldefn.GetFieldCount()):
         fdefn = ldefn.GetFieldDefn(n)
         schema.append(fdefn.name)
-    if 'iseg' in schema:
+    if 'stream_segment' in schema:
         iFlag_segment = 1
     else:
         iFlag_segment = 0   
@@ -35,16 +35,17 @@ def read_mesh_json(iMesh_type_in, sFilename_mesh_in):
     #we also need to spatial reference
     for pFeature_mesh in pLayer_mesh:
         pGeometry_mesh = pFeature_mesh.GetGeometryRef()        
-        dummy0 = loads( pGeometry_mesh.ExportToWkt() )
-        aCoords_gcs = dummy0.exterior.coords
-        aCoords_gcs= np.array(aCoords_gcs)       
-        lCellID = pFeature_mesh.GetField("id")
-        dLon = pFeature_mesh.GetField("lon")
-        dLat = pFeature_mesh.GetField("lat")        
+        #dummy0 = loads( pGeometry_mesh.ExportToWkt() )
+        #aCoords_gcs = dummy0.exterior.coords
+        #aCoords_gcs= np.array(aCoords_gcs)
+        aCoords_gcs = get_geometry_coordinates(pGeometry_mesh)       
+        lCellID = pFeature_mesh.GetField("cellid")
+        dLon = pFeature_mesh.GetField("longitude")
+        dLat = pFeature_mesh.GetField("latitude")        
         dArea = pFeature_mesh.GetField("area")
         if iMesh_type_in == 4:
-            dElevation_mean = pFeature_mesh.GetField("elev")
-            dElevation_profile0 = pFeature_mesh.GetField("elev0")
+            dElevation_mean = pFeature_mesh.GetField("elevation_mean")
+            dElevation_profile0 = pFeature_mesh.GetField("elevation_profile0")
     
         pGeometrytype_mesh = pGeometry_mesh.GetGeometryName()
         if(pGeometrytype_mesh == 'POLYGON'):            
@@ -63,7 +64,7 @@ def read_mesh_json(iMesh_type_in, sFilename_mesh_in):
 
 def read_mesh_json_w_topology(iMesh_type_in, sFilename_mesh_in):
     """
-    convert a shpefile to json format.
+    
     This function should be used for stream flowline only.
     """
     iReturn_code = 1
@@ -84,7 +85,7 @@ def read_mesh_json_w_topology(iMesh_type_in, sFilename_mesh_in):
     for n in range(ldefn.GetFieldCount()):
         fdefn = ldefn.GetFieldDefn(n)
         schema.append(fdefn.name)
-    if 'iseg' in schema:
+    if 'stream_segment' in schema:
         iFlag_segment = 1
     else:
         iFlag_segment = 0   
@@ -92,16 +93,17 @@ def read_mesh_json_w_topology(iMesh_type_in, sFilename_mesh_in):
     #we also need to spatial reference
     for pFeature_mesh in pLayer_mesh:
         pGeometry_mesh = pFeature_mesh.GetGeometryRef()        
-        dummy0 = loads( pGeometry_mesh.ExportToWkt() )
-        aCoords_gcs = dummy0.exterior.coords
-        aCoords_gcs= np.array(aCoords_gcs)       
-        lCellID = pFeature_mesh.GetField("id")
-        dLon = pFeature_mesh.GetField("lon")
-        dLat = pFeature_mesh.GetField("lat")        
+        #dummy0 = loads( pGeometry_mesh.ExportToWkt() )
+        #aCoords_gcs = dummy0.exterior.coords
+        #aCoords_gcs= np.array(aCoords_gcs)      
+        aCoords_gcs = get_geometry_coordinates(pGeometry_mesh)    
+        lCellID = pFeature_mesh.GetField("cellid")
+        dLon = pFeature_mesh.GetField("longitude")
+        dLat = pFeature_mesh.GetField("latitude")        
         dArea = pFeature_mesh.GetField("area")
         if iMesh_type_in == 4:
-            dElevation_mean = pFeature_mesh.GetField("elev")
-            dElevation_profile0 = pFeature_mesh.GetField("elev0")
+            dElevation_mean = pFeature_mesh.GetField("elevation_mean")
+            dElevation_profile0 = pFeature_mesh.GetField("elevation_profile0")
     
         pGeometrytype_mesh = pGeometry_mesh.GetGeometryName()
         if(pGeometrytype_mesh == 'POLYGON'):            
